@@ -1,10 +1,14 @@
+"use strict";
+
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
 
+
 require('../common');
 
 var assert = require('assert/');
+
 var stream = require('../../');
 
 var writable = new stream.Writable();
@@ -25,12 +29,29 @@ writable.on('finish', function () {
   // ending, finished, ended = true.
   testStates(true, true, true);
 });
-
-writable.end('testing function end()', function () {
+var result = writable.end('testing function end()', function () {
   // ending, finished, ended = true.
   testStates(true, true, true);
-});
+}); // end returns the writable instance
 
-// ending, ended = true.
+assert.strictEqual(result, writable); // ending, ended = true.
 // finished = false.
-testStates(true, false, true);
\ No newline at end of file
+
+testStates(true, false, true);
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
+});
\ No newline at end of file
